==> org.eclipse.gemoc.dsl.ui.source_3.0.0.201807171540.jar: org/eclipse/gemoc/ui/highlighting/DslHighlightingConfiguration.java <==
package org.eclipse.gemoc.ui.highlighting;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.xtext.ui.editor.syntaxcoloring.DefaultHighlightingConfiguration;
import org.eclipse.xtext.ui.editor.syntaxcoloring.IHighlightingConfigurationAcceptor;
import org.eclipse.xtext.ui.editor.utils.TextStyle;

@SuppressWarnings("all")
public class DslHighlightingConfiguration extends DefaultHighlightingConfiguration {
  public final static String KEY_ID = "dsl_key";
  
  public final static String VALUE_ID = "dsl_value";
  
  public final static String SEPARATOR_ID = "dsl_separator";
  
  public final static String LINESEPARATOR_ID = "dsl_lineseparator";
  
  @Override
  public void configure(final IHighlightingConfigurationAcceptor acceptor) {
    super.configure(acceptor);
    TextStyle _keyTextStyle = this.keyTextStyle();
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.KEY_ID, "Entry key", _keyTextStyle);
    TextStyle _valueTextStyle = this.valueTextStyle();
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.VALUE_ID, "Entry value", _valueTextStyle);
    TextStyle _separatorTextStyle = this.separatorTextStyle();
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.SEPARATOR_ID, "Entry separator", _separatorTextStyle);
    TextStyle _lineSeparatorTextStyle = this.lineSeparatorTextStyle();
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.LINESEPARATOR_ID, "Line separator", _lineSeparatorTextStyle);
  }
  
  public TextStyle keyTextStyle() {
    TextStyle _defaultTextStyle = this.defaultTextStyle();
    final TextStyle textStyle = _defaultTextStyle.copy();
    RGB _rGB = new RGB(0, 26, 171);
    textStyle.setColor(_rGB);
    return textStyle;
  }
  
  public TextStyle valueTextStyle() {
    TextStyle _defaultTextStyle = this.defaultTextStyle();
    final TextStyle textStyle = _defaultTextStyle.copy();
    textStyle.setStyle(SWT.ITALIC);
    return textStyle;
  }
  
  public TextStyle separatorTextStyle() {
    TextStyle _defaultTextStyle = this.defaultTextStyle();
    final TextStyle textStyle = _defaultTextStyle.copy();
    return textStyle;
  }
  
  public TextStyle lineSeparatorTextStyle() {
    TextStyle _numberTextStyle = this.numberTextStyle();
    final TextStyle textStyle = _numberTextStyle.copy();
    textStyle.setStyle(SWT.NORMAL);
    return textStyle;
  }
}

==> org.eclipse.gemoc.dsl.ui.source_3.0.0.201907291255.jar: org/eclipse/gemoc/ui/highlighting/DslHighlightingConfiguration.java <==
package org.eclipse.gemoc.ui.highlighting;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.xtext.ui.editor.syntaxcoloring.DefaultHighlightingConfiguration;
import org.eclipse.xtext.ui.editor.syntaxcoloring.IHighlightingConfigurationAcceptor;
import org.eclipse.xtext.ui.editor.utils.TextStyle;

@SuppressWarnings("all")
public class DslHighlightingConfiguration extends DefaultHighlightingConfiguration {
  public final static String KEY_ID = "dsl_key";
  
  public final static String VALUE_ID = "dsl_value";
  
  public final static String SEPARATOR_ID = "dsl_separator";
  
  public final static String LINESEPARATOR_ID = "dsl_lineseparator";
  
  @Override
  public void configure(final IHighlightingConfigurationAcceptor acceptor) {
    super.configure(acceptor);
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.KEY_ID, "Entry key", this.keyTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.VALUE_ID, "Entry value", this.valueTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.SEPARATOR_ID, "Entry separator", this.separatorTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.LINESEPARATOR_ID, "Line separator", this.lineSeparatorTextStyle());
  }
  
  public TextStyle keyTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    RGB _rGB = new RGB(0, 26, 171);
    textStyle.setColor(_rGB);
    return textStyle;
  }
  
  public TextStyle valueTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    textStyle.setStyle(SWT.ITALIC);
    return textStyle;
  }
  
  public TextStyle separatorTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    return textStyle;
  }
  
  public TextStyle lineSeparatorTextStyle() {
    final TextStyle textStyle = this.numberTextStyle().copy();
    textStyle.setStyle(SWT.NORMAL);
    return textStyle;
  }
}
